@@ -41,17 +41,22 @@ einstellungen_t::einstellungen_t() :
 	show_pax = true;
 
 	// default climate zones
-	setze_default_climates();
+	set_default_climates();
 	winter_snowline = 7;	// not mediterran
 	grundwasser = -2*Z_TILE_STEP;            //25-Nov-01        Markus Weber    Added
 
 	max_mountain_height = 160;                  //can be 0-160.0  01-Dec-01        Markus Weber    Added
 	map_roughness = 0.6;                        //can be 0-1      01-Dec-01        Markus Weber    Added
 
+	river_number = 16;
+	min_river_length = 16;
+	max_river_length = 256;
+
 	// some settigns more
 	allow_player_change = true;
-	use_timeline = true;
+	use_timeline = 2;
 	starting_year = 1930;
+	starting_month = 0;
 	bits_per_month = 18;
 
 	beginner_mode = false;
@@ -164,11 +169,19 @@ einstellungen_t::einstellungen_t() :
 	way_count_tunnel=8;
 	way_max_bridge_len=15;
 	way_count_leaving_road=25;
+
+	// defualt: joined capacities
+	seperate_halt_capacities = false;
+
+	// this will pay for distance to next change station
+	pay_for_total_distance = TO_PREVIOUS;
+
+	avoid_overcrowding = false;
 }
 
 
 
-void einstellungen_t::setze_default_climates()
+void einstellungen_t::set_default_climates()
 {
 	static sint16 borders[MAX_CLIMATES] = { 0, 0, 0, 3, 6, 8, 10, 10 };
 	memcpy( climate_borders, borders, sizeof(sint16)*MAX_CLIMATES );
@@ -327,9 +340,9 @@ void einstellungen_t::rdwr(loadsave_t *file)
 			uint16 old_multiplier = pak_diagonal_multiplier;
 			file->rdwr_short( old_multiplier, "m" );
 			vehikel_basis_t::set_diagonal_multiplier( pak_diagonal_multiplier, old_multiplier );
+			// since vehicle will need realignment afterwards!
 		}
 
-		// since vehicle will need realignment afterwards!
 		if(file->get_version()>=101000) {
 			// game mechanics
 			file->rdwr_short( origin_x, "ox" );
@@ -405,7 +418,7 @@ void einstellungen_t::rdwr(loadsave_t *file)
 		}
 		else {
 			// name of stops
-			setze_name_language_iso( umgebung_t::language_iso );
+			set_name_language_iso( umgebung_t::language_iso );
 
 			// default AIs active
 			for(  int i=0;  i<MAX_PLAYER_COUNT;  i++  ) {
@@ -425,6 +438,21 @@ void einstellungen_t::rdwr(loadsave_t *file)
 				password[i][0] = 0;
 			}
 		}
+
+		if(file->get_version()>101000) {
+			file->rdwr_bool( seperate_halt_capacities, "" );
+			file->rdwr_byte( pay_for_total_distance, "" );
+
+			file->rdwr_short(starting_month, "");
+
+			file->rdwr_short( river_number, "" );
+			file->rdwr_short( min_river_length, "" );
+			file->rdwr_short( max_river_length, "" );
+		}
+
+		if(file->get_version()>102000) {
+			file->rdwr_bool( avoid_overcrowding, "" );
+		}
 	}
 }
 
@@ -432,78 +460,97 @@ void einstellungen_t::rdwr(loadsave_t *file)
 
 
 // read the settings from this file
-void einstellungen_t::parse_simuconf( tabfile_t &simuconf, sint16 &disp_width, sint16 &disp_height, sint16 &fullscreen, cstring_t &objfilename )
+void einstellungen_t::parse_simuconf( tabfile_t &simuconf, sint16 &disp_width, sint16 &disp_height, sint16 &fullscreen, cstring_t &objfilename, bool einstellungen_only )
 {
 	tabfileobj_t contents;
 
 	simuconf.read(contents);
 
-	umgebung_t::max_convoihandles = contents.get_int("convoys", umgebung_t::max_convoihandles );
-	umgebung_t::max_linehandles = contents.get_int("lines", umgebung_t::max_linehandles );
-	umgebung_t::max_halthandles = contents.get_int("stations", umgebung_t::max_halthandles );
+	if(  !einstellungen_only  ) {
+		umgebung_t::max_convoihandles = contents.get_int("convoys", umgebung_t::max_convoihandles );
+		umgebung_t::max_linehandles = contents.get_int("lines", umgebung_t::max_linehandles );
+		umgebung_t::max_halthandles = contents.get_int("stations", umgebung_t::max_halthandles );
+
+		umgebung_t::water_animation = contents.get_int("water_animation_ms", umgebung_t::water_animation);
+		umgebung_t::ground_object_probability = contents.get_int("random_grounds_probability", umgebung_t::ground_object_probability);
+		umgebung_t::moving_object_probability = contents.get_int("random_wildlife_probability", umgebung_t::moving_object_probability);
+		umgebung_t::drive_on_left = contents.get_int("drive_left", umgebung_t::drive_on_left );
+
+		umgebung_t::verkehrsteilnehmer_info = contents.get_int("pedes_and_car_info", umgebung_t::verkehrsteilnehmer_info) != 0;
+		umgebung_t::tree_info = contents.get_int("tree_info", umgebung_t::tree_info) != 0;
+		umgebung_t::ground_info = contents.get_int("ground_info", umgebung_t::ground_info) != 0;
+		umgebung_t::townhall_info = contents.get_int("townhall_info", umgebung_t::townhall_info) != 0;
+		umgebung_t::single_info = contents.get_int("only_single_info", umgebung_t::single_info);
+
+		umgebung_t::window_buttons_right = contents.get_int("window_buttons_right", umgebung_t::window_buttons_right);
+		umgebung_t::window_frame_active = contents.get_int("window_frame_active", umgebung_t::window_frame_active);
+
+		umgebung_t::show_tooltips = contents.get_int("show_tooltips", umgebung_t::show_tooltips);
+		umgebung_t::tooltip_color = contents.get_int("tooltip_background_color", umgebung_t::tooltip_color);
+		umgebung_t::tooltip_textcolor = contents.get_int("tooltip_text_color", umgebung_t::tooltip_textcolor);
+
+		// display stuff
+		umgebung_t::show_names = contents.get_int("show_names", umgebung_t::show_names);
+		umgebung_t::show_month = contents.get_int("show_month", umgebung_t::show_month);
+		umgebung_t::max_acceleration = contents.get_int("fast_forward", umgebung_t::max_acceleration);
+
+		umgebung_t::intercity_road_length = contents.get_int("intercity_road_length", umgebung_t::intercity_road_length);
+		const char *test = ltrim(contents.get("intercity_road_type"));
+		if(*test  &&  test) {
+			delete umgebung_t::intercity_road_type;
+			umgebung_t::intercity_road_type = strdup(test);
+		}
+
+		// up to ten rivers are possible
+		for(  int i = 0;  i<10;  i++  ) {
+			char name[32];
+			sprintf( name, "river_type[%i]", i );
+			const char *test = ltrim(contents.get(name));
+			if(test  &&  *test) {
+				umgebung_t::river_type[umgebung_t::river_types++] = strdup( test );
+			}
+		}
+
+		umgebung_t::autosave = (contents.get_int("autosave", umgebung_t::autosave));
+		umgebung_t::fps = contents.get_int("frames_per_second",umgebung_t::fps);
+	}
 
 	// routing stuff
 	max_route_steps = contents.get_int("max_route_steps", max_route_steps );
 	max_hops = contents.get_int("max_hops", max_hops );
 	max_transfers = contents.get_int("max_transfers", max_transfers );
 	passenger_factor = contents.get_int("passenger_factor", passenger_factor ); /* this can manipulate the passenger generation */
+	seperate_halt_capacities = contents.get_int("seperate_halt_capacities", seperate_halt_capacities ) != 0;
+	pay_for_total_distance = contents.get_int("pay_for_total_distance", pay_for_total_distance );
+	avoid_overcrowding = contents.get_int("avoid_overcrowding", avoid_overcrowding )!=0;
 
 	fussgaenger = contents.get_int("random_pedestrians", fussgaenger ) != 0;
 	show_pax = contents.get_int("stop_pedestrians", show_pax ) != 0;
 	stadtauto_duration = contents.get_int("default_citycar_life", stadtauto_duration);	// ten normal years
 
-	umgebung_t::water_animation = contents.get_int("water_animation_ms", umgebung_t::water_animation);
-	umgebung_t::ground_object_probability = contents.get_int("random_grounds_probability", umgebung_t::ground_object_probability);
-	umgebung_t::moving_object_probability = contents.get_int("random_wildlife_probability", umgebung_t::moving_object_probability);
-	umgebung_t::drive_on_left = contents.get_int("drive_left", umgebung_t::drive_on_left );
-
-	umgebung_t::verkehrsteilnehmer_info = contents.get_int("pedes_and_car_info", umgebung_t::verkehrsteilnehmer_info) != 0;
-	umgebung_t::tree_info = contents.get_int("tree_info", umgebung_t::tree_info) != 0;
-	umgebung_t::ground_info = contents.get_int("ground_info", umgebung_t::ground_info) != 0;
-	umgebung_t::townhall_info = contents.get_int("townhall_info", umgebung_t::townhall_info) != 0;
-	umgebung_t::single_info = contents.get_int("only_single_info", umgebung_t::single_info);
-
-	umgebung_t::window_buttons_right = contents.get_int("window_buttons_right", umgebung_t::window_buttons_right);
-	umgebung_t::window_frame_active = contents.get_int("window_frame_active", umgebung_t::window_frame_active);
-
-	umgebung_t::show_tooltips = contents.get_int("show_tooltips", umgebung_t::show_tooltips);
-	umgebung_t::tooltip_color = contents.get_int("tooltip_background_color", umgebung_t::tooltip_color);
-	umgebung_t::tooltip_textcolor = contents.get_int("tooltip_text_color", umgebung_t::tooltip_textcolor);
-
 	starting_money = contents.get_int("starting_money", starting_money );
 	maint_building = contents.get_int("maintenance_building", maint_building);
 
 	numbered_stations = contents.get_int("numbered_stations", numbered_stations ) != 0;
 	station_coverage_size = contents.get_int("station_coverage", station_coverage_size );
 
-	// display stuff
-	umgebung_t::show_names = contents.get_int("show_names", umgebung_t::show_names);
-	umgebung_t::show_month = contents.get_int("show_month", umgebung_t::show_month);
-	umgebung_t::max_acceleration = contents.get_int("fast_forward", umgebung_t::max_acceleration);
-
 	// time stuff
 	bits_per_month = contents.get_int("bits_per_month", bits_per_month);
 	use_timeline = contents.get_int("use_timeline", use_timeline);
 	starting_year = contents.get_int("starting_year", starting_year);
+	starting_month = contents.get_int("starting_month", starting_month+1)-1;
 
-	umgebung_t::intercity_road_length = contents.get_int("intercity_road_length", umgebung_t::intercity_road_length);
-	cstring_t *test = new cstring_t(ltrim(contents.get("intercity_road_type")));
-	if(test->len()>0) {
-		delete umgebung_t::intercity_road_type;
-		umgebung_t::intercity_road_type = test;
-	}
-	else {
-		delete test;
-	}
 	const char *str = ltrim(contents.get("city_road_type"));
 	if(str[0]>0) {
 		strncpy( city_road_type, str, 256 );
 		city_road_type[255] = 0;
 	}
 
-	pak_diagonal_multiplier = contents.get_int("diagonal_multiplier", pak_diagonal_multiplier);
+	river_number = contents.get_int("river_number", river_number );
+	min_river_length = contents.get_int("river_min_length", min_river_length );
+	max_river_length = contents.get_int("river_max_length", max_river_length );
 
-	umgebung_t::autosave = (contents.get_int("autosave", umgebung_t::autosave));
+	pak_diagonal_multiplier = contents.get_int("diagonal_multiplier", pak_diagonal_multiplier);
 
 	factory_spacing = contents.get_int("factory_spacing", factory_spacing );
 	crossconnect_factories = contents.get_int("crossconnect_factories", crossconnect_factories ) != 0;
@@ -573,7 +620,6 @@ void einstellungen_t::parse_simuconf( tabfile_t &simuconf, sint16 &disp_width, s
 	disp_width = contents.get_int("display_width", disp_width);
 	disp_height = contents.get_int("display_height", disp_height);
 	fullscreen = contents.get_int("fullscreen", fullscreen);
-	umgebung_t::fps = contents.get_int("frames_per_second",umgebung_t::fps);
 
 	// Default pak file path
 	objfilename = ltrim(contents.get_string("pak_file_path", "" ));
