@@ -71,9 +71,9 @@ gebaeude_t::gebaeude_t(karte_t *welt, loadsave_t *file) : ding_t(welt)
 	init();
 	rdwr(file);
 	if(file->get_version()<88002) {
-		setze_yoff(0);
+		set_yoff(0);
 	}
-	if(tile  &&  tile->gib_phasen()>1) {
+	if(tile  &&  tile->get_phasen()>1) {
 		welt->sync_add( this );
 		sync = true;
 	}
@@ -84,19 +84,19 @@ gebaeude_t::gebaeude_t(karte_t *welt, loadsave_t *file) : ding_t(welt)
 gebaeude_t::gebaeude_t(karte_t *welt, koord3d pos, spieler_t *sp, const haus_tile_besch_t *t) :
     ding_t(welt, pos)
 {
-	setze_besitzer( sp );
+	set_besitzer( sp );
 
 	init();
 	if(t) {
-		setze_tile(t);	// this will set init time etc.
+		set_tile(t);	// this will set init time etc.
 	}
 
 	grund_t *gr=welt->lookup(pos);
-	if(gr  &&  gr->gib_weg_hang()!=gr->gib_grund_hang()) {
-		setze_yoff(-TILE_HEIGHT_STEP);
+	if(gr  &&  gr->get_weg_hang()!=gr->get_grund_hang()) {
+		set_yoff(-TILE_HEIGHT_STEP);
 	}
 
-	spieler_t::add_maintenance(gib_besitzer(), welt->gib_einstellungen()->maint_building*tile->gib_besch()->gib_level() );
+	spieler_t::add_maintenance(get_besitzer(), welt->get_einstellungen()->maint_building*tile->get_besch()->get_level() );
 }
 
 
@@ -112,20 +112,20 @@ gebaeude_t::~gebaeude_t()
 		ptr.stadt->remove_gebaeude_from_stadt(this);
 	}
 
-	if((tile  &&  tile->gib_phasen()>1)  ||  zeige_baugrube) {
+	if((tile  &&  tile->get_phasen()>1)  ||  zeige_baugrube) {
 		sync = false;
 		welt->sync_remove(this);
 	}
 
 	// tiles might be invalid, if no description is found during loading
-	if(tile  &&  tile->gib_besch()  &&  tile->gib_besch()->ist_ausflugsziel()) {
+	if(tile  &&  tile->get_besch()  &&  tile->get_besch()->ist_ausflugsziel()) {
 		welt->remove_ausflugsziel(this);
 	}
 
 	count = 0;
 	anim_time = 0;
 	if(tile) {
-		spieler_t::add_maintenance(gib_besitzer(), -welt->gib_einstellungen()->maint_building*tile->gib_besch()->gib_level() );
+		spieler_t::add_maintenance(get_besitzer(), -welt->get_einstellungen()->maint_building*tile->get_besch()->get_level() );
 	}
 }
 
@@ -137,44 +137,44 @@ gebaeude_t::rotate90()
 	ding_t::rotate90();
 
 	// must or can rotate?
-	const haus_besch_t* const haus_besch = tile->gib_besch();
-	if (is_factory || haus_besch->gib_all_layouts() > 1 || haus_besch->gib_b() * haus_besch->gib_h() > 1) {
-		uint8 layout = tile->gib_layout();
-		koord new_offset = tile->gib_offset();
+	const haus_besch_t* const haus_besch = tile->get_besch();
+	if (is_factory || haus_besch->get_all_layouts() > 1 || haus_besch->get_b() * haus_besch->get_h() > 1) {
+		uint8 layout = tile->get_layout();
+		koord new_offset = tile->get_offset();
 
-		if(haus_besch->gib_all_layouts()<=4) {
-			layout = (layout+3) % haus_besch->gib_all_layouts();
+		if(haus_besch->get_all_layouts()<=4) {
+			layout = (layout+3) % haus_besch->get_all_layouts();
 		}
 		else {
 
 			static uint8 layout_rotate[16] = { 1, 8, 5, 10, 3, 12, 7, 14, 9, 0, 13, 2, 11, 4, 15, 6 };
-			layout = layout_rotate[layout] % haus_besch->gib_all_layouts();
+			layout = layout_rotate[layout] % haus_besch->get_all_layouts();
 		}
 		// have to rotate the tiles :(
-		if (!haus_besch->can_rotate() && haus_besch->gib_all_layouts() == 1 && (welt->gib_einstellungen()->get_rotation() & 1) == 0) {
+		if (!haus_besch->can_rotate() && haus_besch->get_all_layouts() == 1 && (welt->get_einstellungen()->get_rotation() & 1) == 0) {
 			// rotate 180 degree
-			new_offset = koord(haus_besch->gib_b() - 1 - new_offset.x, haus_besch->gib_h() - 1 - new_offset.y);
+			new_offset = koord(haus_besch->get_b() - 1 - new_offset.x, haus_besch->get_h() - 1 - new_offset.y);
 		}
 		else {
 			// rotate on ...
-			new_offset = koord(haus_besch->gib_h(tile->gib_layout()) - 1 - new_offset.y, new_offset.x);
+			new_offset = koord(haus_besch->get_h(tile->get_layout()) - 1 - new_offset.y, new_offset.x);
 		}
 
 		// correct factory zero pos
 		if(is_factory  &&  new_offset==koord(0,0)) {
-			ptr.fab->setze_pos( gib_pos() );
+			ptr.fab->set_pos( get_pos() );
 		}
 
 		// suche a tile exist?
-		if (haus_besch->gib_b(layout) > new_offset.x && haus_besch->gib_h(layout) > new_offset.y) {
-			const haus_tile_besch_t* const new_tile = haus_besch->gib_tile(layout, new_offset.x, new_offset.y);
+		if (haus_besch->get_b(layout) > new_offset.x && haus_besch->get_h(layout) > new_offset.y) {
+			const haus_tile_besch_t* const new_tile = haus_besch->get_tile(layout, new_offset.x, new_offset.y);
 			// add new tile: but make them old (no construction)
 			uint32 old_insta_zeit = insta_zeit;
-			setze_tile( new_tile );
+			set_tile( new_tile );
 			insta_zeit = old_insta_zeit;
-			if (haus_besch->gib_utyp() != haus_besch_t::hafen && !tile->has_image()) {
+			if (haus_besch->get_utyp() != haus_besch_t::hafen && !tile->has_image()) {
 				// may have a rotation, that is not recoverable
-				if(!is_factory  ||  new_offset!=koord(0,0)  ||  ptr.fab->gib_besch()->gib_haus()->gib_tile(0,0,0)==NULL) {
+				if(!is_factory  ||  new_offset!=koord(0,0)  ||  ptr.fab->get_besch()->get_haus()->get_tile(0,0,0)==NULL) {
 					// there are factories without a valid zero tile
 					// => this map rotation cannot be reloaded!
 					welt->set_nosave();
@@ -193,12 +193,12 @@ gebaeude_t::rotate90()
  * @author prissi
  */
 void
-gebaeude_t::setze_fab(fabrik_t *fb)
+gebaeude_t::set_fab(fabrik_t *fb)
 {
 	// sets the pointer in non-zero
 	if(fb) {
 		if(!is_factory  &&  ptr.stadt!=NULL) {
-			dbg->fatal("gebaeude_t::setze_fab()","building already bound to city!");
+			dbg->fatal("gebaeude_t::set_fab()","building already bound to city!");
 		}
 		is_factory = true;
 		ptr.fab = fb;
@@ -214,10 +214,10 @@ gebaeude_t::setze_fab(fabrik_t *fb)
  * @author prissi
  */
 void
-gebaeude_t::setze_stadt(stadt_t *s)
+gebaeude_t::set_stadt(stadt_t *s)
 {
 	if(is_factory  &&  ptr.fab!=NULL) {
-		dbg->fatal("gebaeude_t::setze_stadt()","building already bound to factory!");
+		dbg->fatal("gebaeude_t::set_stadt()","building already bound to factory!");
 	}
 	// sets the pointer in non-zero
 	is_factory = false;
@@ -238,15 +238,15 @@ gebaeude_t::add_alter(uint32 a)
 
 
 void
-gebaeude_t::setze_tile(const haus_tile_besch_t *new_tile)
+gebaeude_t::set_tile(const haus_tile_besch_t *new_tile)
 {
-	insta_zeit = welt->gib_zeit_ms();
+	insta_zeit = welt->get_zeit_ms();
 
 	if(!zeige_baugrube  &&  tile!=NULL) {
 		// mark old tile dirty
 		sint16 ypos = 0;
 		for(  int i=0;  i<256;  i++  ) {
-			image_id bild = gib_bild(i);
+			image_id bild = get_bild(i);
 			if(bild==IMG_LEER) {
 				break;
 			}
@@ -255,18 +255,18 @@ gebaeude_t::setze_tile(const haus_tile_besch_t *new_tile)
 		}
 	}
 
-	zeige_baugrube = !new_tile->gib_besch()->ist_ohne_grube();
+	zeige_baugrube = !new_tile->get_besch()->ist_ohne_grube();
 	if(sync) {
-		if(new_tile->gib_phasen()<=1  &&  !zeige_baugrube) {
+		if(new_tile->get_phasen()<=1  &&  !zeige_baugrube) {
 			// need to stop animation
 			welt->sync_remove(this);
 			sync = false;
 			count = 0;
 		}
 	}
-	else if(new_tile->gib_phasen()>1  ||  zeige_baugrube) {
+	else if(new_tile->get_phasen()>1  ||  zeige_baugrube) {
 		// needs now anymation
-		count = simrand(new_tile->gib_phasen());
+		count = simrand(new_tile->get_phasen());
 		anim_time = 0;
 		welt->sync_add(this);
 		sync = true;
@@ -288,11 +288,11 @@ bool gebaeude_t::sync_step(long delta_t)
 {
 	if(zeige_baugrube) {
 		// still under construction?
-		if(welt->gib_zeit_ms() - insta_zeit > 5000) {
+		if(welt->get_zeit_ms() - insta_zeit > 5000) {
 			set_flag(ding_t::dirty);
-			mark_image_dirty(gib_bild(),0);
+			mark_image_dirty(get_bild(),0);
 			zeige_baugrube = false;
-			if(tile->gib_phasen()<=1) {
+			if(tile->get_phasen()<=1) {
 				welt->sync_remove( this );
 				sync = false;
 			}
@@ -301,14 +301,16 @@ bool gebaeude_t::sync_step(long delta_t)
 	else {
 		// normal animated building
 		anim_time += delta_t;
-		if(anim_time>tile->gib_besch()->get_animation_time()) {
+		if(anim_time>tile->get_besch()->get_animation_time()) {
 			if(!zeige_baugrube)  {
 
 				// old positions need redraw
-				image_id bild = gib_bild(0);
-				if(bild!=IMG_LEER) {
+				if(  tile->is_hintergrund_phases( get_pos().z>=welt->get_snowline() )  ) {
+					// the background is animated
+					set_flag(ding_t::dirty);
+					// we must take care of the tiles above
 					for(int i=1;  ;  i++) {
-						bild = gib_bild(i);
+						image_id bild = get_bild(i);
 						if(bild==IMG_LEER) {
 							break;
 						}
@@ -317,17 +319,19 @@ bool gebaeude_t::sync_step(long delta_t)
 				}
 				else {
 					// try foreground
-					bild = gib_after_bild();
+					image_id bild = tile->get_vordergrund(count, get_pos().z>=welt->get_snowline());
+					mark_image_dirty(bild,0);
+					// next phase must be marked dirty too ...
+					bild = tile->get_vordergrund( count+1>=tile->get_phasen()?0:count+1, get_pos().z>=welt->get_snowline());
 					mark_image_dirty(bild,0);
 				}
 
-				anim_time %= tile->gib_besch()->get_animation_time();
+				anim_time %= tile->get_besch()->get_animation_time();
 				count ++;
-				if(count >= tile->gib_phasen()) {
+				if(count >= tile->get_phasen()) {
 					count = 0;
 				}
 				// winter for buildings only above snowline
-				set_flag(ding_t::dirty);
 			}
 		}
 	}
@@ -340,10 +344,10 @@ void
 gebaeude_t::calc_bild()
 {
 	// need no ground?
-	if(!tile->gib_besch()->ist_mit_boden()  ||  !tile->has_image()) {
-		grund_t *gr=welt->lookup(gib_pos());
-		if(gr  &&  gr->gib_typ()==grund_t::fundament) {
-			gr->setze_bild( IMG_LEER );
+	if(!tile->get_besch()->ist_mit_boden()  ||  !tile->has_image()) {
+		grund_t *gr=welt->lookup(get_pos());
+		if(gr  &&  gr->get_typ()==grund_t::fundament) {
+			gr->set_bild( IMG_LEER );
 		}
 	}
 }
@@ -351,45 +355,45 @@ gebaeude_t::calc_bild()
 
 
 image_id
-gebaeude_t::gib_bild() const
+gebaeude_t::get_bild() const
 {
 	if(umgebung_t::hide_buildings!=0) {
 		// opaque houses
-		if(gib_haustyp()!=unbekannt) {
-			return umgebung_t::hide_with_transparency ? skinverwaltung_t::fussweg->gib_bild_nr(0) : skinverwaltung_t::construction_site->gib_bild_nr(0);
-		} else if(  (umgebung_t::hide_buildings == umgebung_t::ALL_HIDDEN_BUIDLING  &&  tile->gib_besch()->gib_utyp() < haus_besch_t::weitere)  ||  !tile->has_image()) {
+		if(get_haustyp()!=unbekannt) {
+			return umgebung_t::hide_with_transparency ? skinverwaltung_t::fussweg->get_bild_nr(0) : skinverwaltung_t::construction_site->get_bild_nr(0);
+		} else if(  (umgebung_t::hide_buildings == umgebung_t::ALL_HIDDEN_BUIDLING  &&  tile->get_besch()->get_utyp() < haus_besch_t::weitere)  ||  !tile->has_image()) {
 			// hide with transparency or tile without information
 			if(umgebung_t::hide_with_transparency) {
-				if(tile->gib_besch()->gib_utyp() == haus_besch_t::fabrik  &&  ptr.fab->gib_besch()->gib_platzierung() == fabrik_besch_t::Wasser) {
+				if(tile->get_besch()->get_utyp() == haus_besch_t::fabrik  &&  ptr.fab->get_besch()->get_platzierung() == fabrik_besch_t::Wasser) {
 					// no ground tiles for water thingies
 					return IMG_LEER;
 				}
-				return skinverwaltung_t::fussweg->gib_bild_nr(0);
+				return skinverwaltung_t::fussweg->get_bild_nr(0);
 			}
 			else {
-				int kind=skinverwaltung_t::construction_site->gib_bild_anzahl()<=tile->gib_besch()->gib_utyp() ? skinverwaltung_t::construction_site->gib_bild_anzahl()-1 : tile->gib_besch()->gib_utyp();
-				return skinverwaltung_t::construction_site->gib_bild_nr( kind );
+				int kind=skinverwaltung_t::construction_site->get_bild_anzahl()<=tile->get_besch()->get_utyp() ? skinverwaltung_t::construction_site->get_bild_anzahl()-1 : tile->get_besch()->get_utyp();
+				return skinverwaltung_t::construction_site->get_bild_nr( kind );
 			}
 		}
 	}
 
 	// winter for buildings only above snowline
 	if(zeige_baugrube)  {
-		return skinverwaltung_t::construction_site->gib_bild_nr(0);
+		return skinverwaltung_t::construction_site->get_bild_nr(0);
 	}
 	else {
-		return tile->gib_hintergrund(count, 0, gib_pos().z>=welt->get_snowline());
+		return tile->get_hintergrund(count, 0, get_pos().z>=welt->get_snowline());
 	}
 }
 
 
 
 image_id
-gebaeude_t::gib_outline_bild() const
+gebaeude_t::get_outline_bild() const
 {
 	if(umgebung_t::hide_buildings!=0  &&  umgebung_t::hide_with_transparency  &&  !zeige_baugrube) {
 		// opaque houses
-		return tile->gib_hintergrund(count, 0, gib_pos().z>=welt->get_snowline());
+		return tile->get_hintergrund(count, 0, get_pos().z>=welt->get_snowline());
 	}
 	return IMG_LEER;
 }
@@ -398,16 +402,16 @@ gebaeude_t::gib_outline_bild() const
 
 /* gives outline colour and plots background tile if needed for transparent view */
 PLAYER_COLOR_VAL
-gebaeude_t::gib_outline_colour() const
+gebaeude_t::get_outline_colour() const
 {
 	COLOR_VAL colours[] = { COL_BLACK, COL_YELLOW, COL_YELLOW, COL_PURPLE, COL_RED, COL_GREEN };
 	PLAYER_COLOR_VAL disp_colour = 0;
 	if(umgebung_t::hide_buildings!=umgebung_t::NOT_HIDE) {
-		if(gib_haustyp()!=unbekannt) {
+		if(get_haustyp()!=unbekannt) {
 			disp_colour = colours[0] | TRANSPARENT50_FLAG | OUTLINE_FLAG;
-		} else if (umgebung_t::hide_buildings == umgebung_t::ALL_HIDDEN_BUIDLING && tile->gib_besch()->gib_utyp() < haus_besch_t::weitere) {
+		} else if (umgebung_t::hide_buildings == umgebung_t::ALL_HIDDEN_BUIDLING && tile->get_besch()->get_utyp() < haus_besch_t::weitere) {
 			// special bilding
-			disp_colour = colours[tile->gib_besch()->gib_utyp()] | TRANSPARENT50_FLAG | OUTLINE_FLAG;
+			disp_colour = colours[tile->get_besch()->get_utyp()] | TRANSPARENT50_FLAG | OUTLINE_FLAG;
 		}
 	}
 	return disp_colour;
@@ -416,31 +420,31 @@ gebaeude_t::gib_outline_colour() const
 
 
 image_id
-gebaeude_t::gib_bild(int nr) const
+gebaeude_t::get_bild(int nr) const
 {
 	if(zeige_baugrube || umgebung_t::hide_buildings) {
 		return IMG_LEER;
 	}
 	else {
 		// winter for buildings only above snowline
-		return tile->gib_hintergrund(count, nr, gib_pos().z>=welt->get_snowline());
+		return tile->get_hintergrund(count, nr, get_pos().z>=welt->get_snowline());
 	}
 }
 
 
 
 image_id
-gebaeude_t::gib_after_bild() const
+gebaeude_t::get_after_bild() const
 {
 	if(zeige_baugrube) {
 		return IMG_LEER;
 	}
-	if (umgebung_t::hide_buildings != 0 && tile->gib_besch()->gib_utyp() < haus_besch_t::weitere) {
+	if (umgebung_t::hide_buildings != 0 && tile->get_besch()->get_utyp() < haus_besch_t::weitere) {
 		return IMG_LEER;
 	}
 	else {
 		// Show depots, station buildings etc.
-		return tile->gib_vordergrund(count, gib_pos().z>=welt->get_snowline());
+		return tile->get_vordergrund(count, get_pos().z>=welt->get_snowline());
 	}
 }
 
@@ -449,23 +453,23 @@ gebaeude_t::gib_after_bild() const
 /*
  * calculate the passenger level as funtion of the city size (if there)
  */
-int gebaeude_t::gib_passagier_level() const
+int gebaeude_t::get_passagier_level() const
 {
-	koord dim = tile->gib_besch()->gib_groesse();
-	long pax = tile->gib_besch()->gib_level();
+	koord dim = tile->get_besch()->get_groesse();
+	long pax = tile->get_besch()->get_level();
 	if (!is_factory && ptr.stadt != NULL) {
 		// belongs to a city ...
-		return (((pax+6)>>2)*welt->gib_einstellungen()->gib_passenger_factor())/16;
+		return (((pax+6)>>2)*welt->get_einstellungen()->get_passenger_factor())/16;
 	}
 	return pax*dim.x*dim.y;
 }
 
-int gebaeude_t::gib_post_level() const
+int gebaeude_t::get_post_level() const
 {
-	koord dim = tile->gib_besch()->gib_groesse();
-	long post = tile->gib_besch()->gib_post_level();
+	koord dim = tile->get_besch()->get_groesse();
+	long post = tile->get_besch()->get_post_level();
 	if (!is_factory && ptr.stadt != NULL) {
-		return (((post+5)>>2)*welt->gib_einstellungen()->gib_passenger_factor())/16;
+		return (((post+5)>>2)*welt->get_einstellungen()->get_passenger_factor())/16;
 	}
 	return post*dim.x*dim.y;
 }
@@ -476,12 +480,12 @@ int gebaeude_t::gib_post_level() const
  * @return eigener Name oder Name der Fabrik falls Teil einer Fabrik
  * @author Hj. Malthaner
  */
-const char *gebaeude_t::gib_name() const
+const char *gebaeude_t::get_name() const
 {
 	if(is_factory  &&  ptr.fab) {
-		return ptr.fab->gib_name();
+		return ptr.fab->get_name();
 	}
-	switch(tile->gib_besch()->gib_typ()) {
+	switch(tile->get_besch()->get_typ()) {
 		case wohnung:
 			break;//return "Wohnhaus";
 		case gewerbe:
@@ -489,7 +493,7 @@ const char *gebaeude_t::gib_name() const
 		case industrie:
 			break;//return "Industriegebude";
 		default:
-			switch(tile->gib_besch()->gib_utyp()) {
+			switch(tile->get_besch()->get_utyp()) {
 				case haus_besch_t::attraction_city:   return "Besonderes Gebaeude";
 				case haus_besch_t::attraction_land:   return "Sehenswuerdigkeit";
 				case haus_besch_t::denkmal:           return "Denkmal";
@@ -503,22 +507,22 @@ const char *gebaeude_t::gib_name() const
 
 bool gebaeude_t::ist_rathaus() const
 {
-	return tile->gib_besch()->ist_rathaus();
+	return tile->get_besch()->ist_rathaus();
 }
 
 bool gebaeude_t::is_monument() const
 {
-	return tile->gib_besch()->gib_utyp() == haus_besch_t::denkmal;
+	return tile->get_besch()->get_utyp() == haus_besch_t::denkmal;
 }
 
 bool gebaeude_t::ist_firmensitz() const
 {
-	return tile->gib_besch()->ist_firmensitz();
+	return tile->get_besch()->ist_firmensitz();
 }
 
-gebaeude_t::typ gebaeude_t::gib_haustyp() const
+gebaeude_t::typ gebaeude_t::get_haustyp() const
 {
-	return tile->gib_besch()->gib_typ();
+	return tile->get_besch()->get_typ();
 }
 
 
@@ -528,11 +532,11 @@ gebaeude_t::zeige_info()
 	// Fr die Anzeige ist bei mehrteiliggen Gebuden immer
 	// das erste laut Layoutreihenfolge zustndig.
 	// Sonst gibt es fr eine 2x2-Fabrik bis zu 4 Infofenster.
-	koord k = tile->gib_offset();
+	koord k = tile->get_offset();
 	if(k != koord(0, 0)) {
-		grund_t *gr = welt->lookup(gib_pos() - k);
+		grund_t *gr = welt->lookup(get_pos() - k);
 		if(!gr) {
-			gr = welt->lookup_kartenboden(gib_pos().gib_2d() - k);
+			gr = welt->lookup_kartenboden(get_pos().get_2d() - k);
 		}
 		gebaeude_t* gb = gr->find<gebaeude_t>();
 		// is the info of the (0,0) tile on multi tile buildings
@@ -542,23 +546,23 @@ gebaeude_t::zeige_info()
 		}
 	}
 	else {
-DBG_MESSAGE("gebaeude_t::zeige_info()", "at %d,%d - name is '%s'", gib_pos().x, gib_pos().y, gib_name());
+DBG_MESSAGE("gebaeude_t::zeige_info()", "at %d,%d - name is '%s'", get_pos().x, get_pos().y, get_name());
 
 		if(get_fabrik()) {
 			ptr.fab->zeige_info();
 		}
 		else if(ist_firmensitz()) {
 			int old_count = win_get_open_count();
-			create_win( new money_frame_t(gib_besitzer()), w_info, (long)gib_besitzer() );
+			create_win( new money_frame_t(get_besitzer()), w_info, (long)get_besitzer() );
 			// already open?
 			if(umgebung_t::townhall_info  &&  old_count==win_get_open_count()) {
 				create_win( new ding_infowin_t(this), w_info, (long)this);
 			}
 		}
-		else if(!tile->gib_besch()->ist_ohne_info()) {
+		else if(!tile->get_besch()->ist_ohne_info()) {
 			if(ist_rathaus()) {
 				int old_count = win_get_open_count();
-				welt->suche_naechste_stadt(gib_pos().gib_2d())->zeige_info();
+				welt->suche_naechste_stadt(get_pos().get_2d())->zeige_info();
 				// already open?
 				if(umgebung_t::townhall_info  &&  old_count==win_get_open_count()) {
 					create_win( new ding_infowin_t(this), w_info, (long)this);
@@ -585,12 +589,12 @@ void gebaeude_t::info(cbuffer_t & buf) const
 		buf.append("\n");
 	}
 	else {
-		const char *desc = tile->gib_besch()->gib_name();
+		const char *desc = tile->get_besch()->get_name();
 		if(desc != NULL) {
 			const char *trans_desc = translator::translate(desc);
 			if(trans_desc==desc) {
 				// no descrition here
-				switch(gib_haustyp()) {
+				switch(get_haustyp()) {
 					case wohnung:
 						trans_desc = translator::translate("residential house");
 						break;
@@ -637,37 +641,37 @@ void gebaeude_t::info(cbuffer_t & buf) const
 		// belongs to which city?
 		if (!is_factory && ptr.stadt != NULL) {
 			char buffer[256];
-			sprintf(buffer,translator::translate("Town: %s\n"),ptr.stadt->gib_name());
+			sprintf(buffer,translator::translate("Town: %s\n"),ptr.stadt->get_name());
 			buf.append(buffer);
 		}
 
 		buf.append(translator::translate("Passagierrate"));
 		buf.append(": ");
-		buf.append(gib_passagier_level());
+		buf.append(get_passagier_level());
 		buf.append("\n");
 
 		buf.append(translator::translate("Postrate"));
 		buf.append(": ");
-		buf.append(gib_post_level());
+		buf.append(get_post_level());
 		buf.append("\n");
 
 		buf.append(translator::translate("\nBauzeit von"));
-		buf.append(tile->gib_besch()->get_intro_year_month()/12);
-		if(tile->gib_besch()->get_retire_year_month()!=DEFAULT_RETIRE_DATE*12) {
+		buf.append(tile->get_besch()->get_intro_year_month()/12);
+		if(tile->get_besch()->get_retire_year_month()!=DEFAULT_RETIRE_DATE*12) {
 			buf.append(translator::translate("\nBauzeit bis"));
-			buf.append(tile->gib_besch()->get_retire_year_month()/12);
+			buf.append(tile->get_besch()->get_retire_year_month()/12);
 		}
 
 		buf.append("\n");
-		if(gib_besitzer()==NULL) {
+		if(get_besitzer()==NULL) {
 			buf.append("\n");
 			buf.append(translator::translate("Wert"));
 			buf.append(": ");
-			buf.append(-welt->gib_einstellungen()->cst_multiply_remove_haus*(tile->gib_besch()->gib_level()+1)/100);
+			buf.append(-welt->get_einstellungen()->cst_multiply_remove_haus*(tile->get_besch()->get_level()+1)/100);
 			buf.append("$\n");
 		}
 
-		const char *maker=tile->gib_besch()->gib_copyright();
+		const char *maker=tile->get_besch()->get_copyright();
 		if(maker!=NULL  && maker[0]!=0) {
 			buf.append("\n");
 			buf.printf(translator::translate("Constructed by %s"), maker);
@@ -690,9 +694,9 @@ gebaeude_t::rdwr(loadsave_t *file)
 	short idx;
 
 	if(file->is_saving()) {
-		const char *s = tile->gib_besch()->gib_name();
+		const char *s = tile->get_besch()->get_name();
 		file->rdwr_str(s);
-		idx = tile->gib_index();
+		idx = tile->get_index();
 	}
 	else {
 		file->rdwr_str(buf, 128 );
@@ -760,39 +764,39 @@ gebaeude_t::rdwr(loadsave_t *file)
 				switch(type) {
 					case gebaeude_t::wohnung:
 						{
-							const haus_besch_t *hb = hausbauer_t::gib_wohnhaus(level,welt->get_timeline_year_month(),welt->get_climate(gib_pos().z));
+							const haus_besch_t *hb = hausbauer_t::get_wohnhaus(level,welt->get_timeline_year_month(),welt->get_climate(get_pos().z));
 							if(hb==NULL) {
-								hb = hausbauer_t::gib_wohnhaus(level,0, MAX_CLIMATES );
+								hb = hausbauer_t::get_wohnhaus(level,0, MAX_CLIMATES );
 							}
-							dbg->message("gebaeude_t::rwdr", "replace unknown building %s with residence level %i by %s",buf,level,hb->gib_name());
-							tile = hb->gib_tile(0);
+							dbg->message("gebaeude_t::rwdr", "replace unknown building %s with residence level %i by %s",buf,level,hb->get_name());
+							tile = hb->get_tile(0);
 						}
 						break;
 
 					case gebaeude_t::gewerbe:
 						{
-							const haus_besch_t *hb = hausbauer_t::gib_gewerbe(level,welt->get_timeline_year_month(),welt->get_climate(gib_pos().z));
+							const haus_besch_t *hb = hausbauer_t::get_gewerbe(level,welt->get_timeline_year_month(),welt->get_climate(get_pos().z));
 							if(hb==NULL) {
-								hb = hausbauer_t::gib_gewerbe(level,0, MAX_CLIMATES );
+								hb = hausbauer_t::get_gewerbe(level,0, MAX_CLIMATES );
 							}
-							dbg->message("gebaeude_t::rwdr", "replace unknown building %s with commercial level %i by %s",buf,level,hb->gib_name());
-							tile = hb->gib_tile(0);
+							dbg->message("gebaeude_t::rwdr", "replace unknown building %s with commercial level %i by %s",buf,level,hb->get_name());
+							tile = hb->get_tile(0);
 						}
 						break;
 
 					case gebaeude_t::industrie:
 						{
-							const haus_besch_t *hb = hausbauer_t::gib_industrie(level,welt->get_timeline_year_month(),welt->get_climate(gib_pos().z));
+							const haus_besch_t *hb = hausbauer_t::get_industrie(level,welt->get_timeline_year_month(),welt->get_climate(get_pos().z));
 							if(hb==NULL) {
-								hb = hausbauer_t::gib_industrie(level,0, MAX_CLIMATES );
+								hb = hausbauer_t::get_industrie(level,0, MAX_CLIMATES );
 							}
-							dbg->message("gebaeude_t::rwdr", "replace unknown building %s with industrie level %i by %s",buf,level,hb->gib_name());
-							tile = hb->gib_tile(0);
+							dbg->message("gebaeude_t::rwdr", "replace unknown building %s with industrie level %i by %s",buf,level,hb->get_name());
+							tile = hb->get_tile(0);
 						}
 						break;
 
 					default:
-						dbg->warning("gebaeude_t::rwdr", "description %s for building at %d,%d not found (will be removed)!", buf, gib_pos().x, gib_pos().y);
+						dbg->warning("gebaeude_t::rwdr", "description %s for building at %d,%d not found (will be removed)!", buf, get_pos().x, get_pos().y);
 				}
 			}
 		}	// here we should have a valid tile pointer or nothing ...
@@ -800,8 +804,8 @@ gebaeude_t::rdwr(loadsave_t *file)
 		/* avoid double contruction of monuments:
 		 * remove them from selection lists
 		 */
-		if (tile  &&  tile->gib_besch()->gib_utyp() == haus_besch_t::denkmal) {
-			hausbauer_t::denkmal_gebaut(tile->gib_besch());
+		if (tile  &&  tile->get_besch()->get_utyp() == haus_besch_t::denkmal) {
+			hausbauer_t::denkmal_gebaut(tile->get_besch());
 		}
 	}
 
@@ -815,11 +819,11 @@ gebaeude_t::rdwr(loadsave_t *file)
 	if(  file->get_version()>=99014  ) {
 		sint32 city_index = -1;
 		if(  file->is_saving()  &&  ptr.stadt!=NULL  ) {
-			city_index = welt->gib_staedte().index_of( ptr.stadt );
+			city_index = welt->get_staedte().index_of( ptr.stadt );
 		}
 		file->rdwr_long( city_index, "c" );
 		if(  file->is_loading()  &&  city_index!=-1  ) {
-			ptr.stadt = welt->gib_staedte()[city_index];
+			ptr.stadt = welt->get_staedte()[city_index];
 		}
 	}
 
@@ -829,7 +833,7 @@ gebaeude_t::rdwr(loadsave_t *file)
 		sync = false;
 
 		// Hajo: rebuild tourist attraction list
-		if(tile && tile->gib_besch()->ist_ausflugsziel()) {
+		if(tile && tile->get_besch()->ist_ausflugsziel()) {
 			welt->add_ausflugsziel( this );
 		}
 	}
@@ -848,11 +852,11 @@ gebaeude_t::laden_abschliessen()
 {
 	calc_bild();
 
-	spieler_t::add_maintenance(gib_besitzer(), welt->gib_einstellungen()->maint_building*tile->gib_besch()->gib_level() );
+	spieler_t::add_maintenance(get_besitzer(), welt->get_einstellungen()->maint_building*tile->get_besch()->get_level() );
 
 	// citybuilding, but no town?
-	if(tile->gib_offset()==koord(0,0)  &&  tile->gib_besch()->is_connected_with_town()) {
-		stadt_t *city = (ptr.stadt==NULL) ? welt->suche_naechste_stadt( gib_pos().gib_2d() ) : ptr.stadt;
+	if(tile->get_offset()==koord(0,0)  &&  tile->get_besch()->is_connected_with_town()) {
+		stadt_t *city = (ptr.stadt==NULL) ? welt->suche_naechste_stadt( get_pos().get_2d() ) : ptr.stadt;
 		if(city) {
 			city->add_gebaeude_to_stadt(this);
 		}
@@ -865,61 +869,61 @@ void gebaeude_t::entferne(spieler_t *sp)
 {
 //	DBG_MESSAGE("gebaeude_t::entferne()","gb %i");
 	// remove costs
-	if(tile->gib_besch()->gib_utyp()<haus_besch_t::bahnhof) {
-		spieler_t::accounting(sp, welt->gib_einstellungen()->cst_multiply_remove_haus*(tile->gib_besch()->gib_level()+1), gib_pos().gib_2d(), COST_CONSTRUCTION);
+	if(tile->get_besch()->get_utyp()<haus_besch_t::bahnhof) {
+		spieler_t::accounting(sp, welt->get_einstellungen()->cst_multiply_remove_haus*(tile->get_besch()->get_level()+1), get_pos().get_2d(), COST_CONSTRUCTION);
 	}
 	else {
 		// tearing down halts is always single costs only
-		spieler_t::accounting(sp, welt->gib_einstellungen()->cst_multiply_remove_haus, gib_pos().gib_2d(), COST_CONSTRUCTION);
+		spieler_t::accounting(sp, welt->get_einstellungen()->cst_multiply_remove_haus, get_pos().get_2d(), COST_CONSTRUCTION);
 	}
 
 	// may need to update next buildings, in the case of start, middle, end buildings
-	if(tile->gib_besch()->gib_all_layouts()>1  &&  gib_haustyp()==unbekannt) {
+	if(tile->get_besch()->get_all_layouts()>1  &&  get_haustyp()==unbekannt) {
 
 		// realign surrounding buildings...
-		uint32 layout = tile->gib_layout();
+		uint32 layout = tile->get_layout();
 
 		// detect if we are connected at far (north/west) end
-		grund_t * gr = welt->lookup( gib_pos() );
+		grund_t * gr = welt->lookup( get_pos() );
 		if(gr) {
-			sint8 offset = gr->gib_weg_yoff()/TILE_HEIGHT_STEP;
-			gr = welt->lookup( gib_pos()+koord3d( (layout & 1 ? koord::ost : koord::sued), offset) );
+			sint8 offset = gr->get_weg_yoff()/TILE_HEIGHT_STEP;
+			gr = welt->lookup( get_pos()+koord3d( (layout & 1 ? koord::ost : koord::sued), offset) );
 			if(!gr) {
 				// check whether bridge end tile
-				grund_t * gr_tmp = welt->lookup( gib_pos()+koord3d( (layout & 1 ? koord::ost : koord::sued),offset - 1) );
-				if(gr_tmp && gr_tmp->gib_weg_yoff()/TILE_HEIGHT_STEP == 1) {
+				grund_t * gr_tmp = welt->lookup( get_pos()+koord3d( (layout & 1 ? koord::ost : koord::sued),offset - 1) );
+				if(gr_tmp && gr_tmp->get_weg_yoff()/TILE_HEIGHT_STEP == 1) {
 					gr = gr_tmp;
 				}
 			}
 			if(gr) {
 				gebaeude_t* gb = gr->find<gebaeude_t>();
-				if(gb  &&  gb->gib_tile()->gib_besch()->gib_all_layouts()>4u) {
-					koord xy = gb->gib_tile()->gib_offset();
-					uint8 layoutbase = gb->gib_tile()->gib_layout();
+				if(gb  &&  gb->get_tile()->get_besch()->get_all_layouts()>4u) {
+					koord xy = gb->get_tile()->get_offset();
+					uint8 layoutbase = gb->get_tile()->get_layout();
 					if((layoutbase & 1u) == (layout & 1u)) {
 						layoutbase |= 4u; // set far bit on neighbour
-						gb->setze_tile(gb->gib_tile()->gib_besch()->gib_tile(layoutbase, xy.x, xy.y));
+						gb->set_tile(gb->get_tile()->get_besch()->get_tile(layoutbase, xy.x, xy.y));
 					}
 				}
 			}
 
 			// detect if near (south/east) end
-			gr = welt->lookup( gib_pos()+koord3d( (layout & 1 ? koord::west : koord::nord), offset) );
+			gr = welt->lookup( get_pos()+koord3d( (layout & 1 ? koord::west : koord::nord), offset) );
 			if(!gr) {
 				// check whether bridge end tile
-				grund_t * gr_tmp = welt->lookup( gib_pos()+koord3d( (layout & 1 ? koord::west : koord::nord),offset - 1) );
-				if(gr_tmp && gr_tmp->gib_weg_yoff()/TILE_HEIGHT_STEP == 1) {
+				grund_t * gr_tmp = welt->lookup( get_pos()+koord3d( (layout & 1 ? koord::west : koord::nord),offset - 1) );
+				if(gr_tmp && gr_tmp->get_weg_yoff()/TILE_HEIGHT_STEP == 1) {
 					gr = gr_tmp;
 				}
 			}
 			if(gr) {
 				gebaeude_t* gb = gr->find<gebaeude_t>();
-				if(gb  &&  gb->gib_tile()->gib_besch()->gib_all_layouts()>4) {
-					koord xy = gb->gib_tile()->gib_offset();
-					uint8 layoutbase = gb->gib_tile()->gib_layout();
+				if(gb  &&  gb->get_tile()->get_besch()->get_all_layouts()>4) {
+					koord xy = gb->get_tile()->get_offset();
+					uint8 layoutbase = gb->get_tile()->get_layout();
 					if((layoutbase & 1u) == (layout & 1u)) {
 						layoutbase |= 2u; // set near bit on neighbour
-						gb->setze_tile(gb->gib_tile()->gib_besch()->gib_tile(layoutbase, xy.x, xy.y));
+						gb->set_tile(gb->get_tile()->get_besch()->get_tile(layoutbase, xy.x, xy.y));
 					}
 				}
 			}
@@ -927,7 +931,7 @@ void gebaeude_t::entferne(spieler_t *sp)
 	}
 
 	// remove all traces from the screen
-	for(  int i=0;  gib_bild(i)!=IMG_LEER;  i++ ) {
-		mark_image_dirty( gib_bild(i), -get_tile_raster_width()*i );
+	for(  int i=0;  get_bild(i)!=IMG_LEER;  i++ ) {
+		mark_image_dirty( get_bild(i), -get_tile_raster_width()*i );
 	}
 }
