@@ -30,12 +30,12 @@ public:
 	// needs to check for hiding asymmetric pillars
 	void laden_abschliessen();
 
-	const char* gib_name() const { return "Pillar"; }
-	enum ding_t::typ gib_typ() const { return ding_t::pillar; }
+	const char* get_name() const { return "Pillar"; }
+	enum ding_t::typ get_typ() const { return ding_t::pillar; }
 
-	const bruecke_besch_t* gib_besch() const { return besch; }
+	const bruecke_besch_t* get_besch() const { return besch; }
 
-	image_id gib_bild() const { return hide ? IMG_LEER : besch->gib_hintergrund((bruecke_besch_t::img_t)dir, gib_pos().z >= welt->get_snowline()); }
+	image_id get_bild() const { return hide ? IMG_LEER : besch->get_hintergrund((bruecke_besch_t::img_t)dir, get_pos().z >= welt->get_snowline()); }
 
 	/**
 	 * @return Einen Beschreibungsstring fr das Objekt, der z.B. in einem
