@@ -44,7 +44,7 @@ public:
 	 * @return den Dateinamen fr die Hilfe, oder NULL
 	 * @author Hj. Malthaner
 	 */
-	const char *gib_hilfe_datei() const { return "load_relief.txt"; }
+	const char *get_hilfe_datei() const { return "load_relief.txt"; }
 
 	load_relief_frame_t(einstellungen_t* sets);
 };
