@@ -84,7 +84,7 @@ static font_type large_font = { 0, 0, 0, NULL, NULL };
 int large_font_height = 10;
 
 #define LIGHT_COUNT (15)
-#define MAX_PLAYER (16)
+#define MAX_PLAYER_COUNT (16)
 
 #define RGBMAPSIZE (0x8000+LIGHT_COUNT+16)
 
@@ -129,7 +129,7 @@ static PIXVAL specialcolormap_all_day[256];
 
 
 // offsets of first and second comany color
-static uint8 player_offsets[MAX_PLAYER][2];
+static uint8 player_offsets[MAX_PLAYER_COUNT][2];
 
 
 /*
@@ -530,7 +530,7 @@ KOORD_VAL display_set_base_raster_width(KOORD_VAL new_raster)
  */
 static void rezoom(void)
 {
-	unsigned int n;
+	uint16 n;
 
 	for (n = 0; n < anz_images; n++) {
 		if((images[n].recode_flags & FLAG_ZOOMABLE) != 0 && images[n].base_h > 0) {
@@ -576,11 +576,9 @@ int zoom_factor_down()
 static inline void mark_tile_dirty(const int x, const int y)
 {
 	const int bit = x + y * tiles_per_line;
-
 #if 0
 	assert(bit / 8 < tile_buffer_length);
 #endif
-
 	tile_dirty[bit >> 3] |= 1 << (bit & 7);
 }
 
@@ -656,7 +654,7 @@ void mark_rect_dirty_wc(KOORD_VAL x1, KOORD_VAL y1, KOORD_VAL x2, KOORD_VAL y2)
 
 static uint8 player_night=0xFF;
 static uint8 player_day=0xFF;
-static void	activate_player_color(sint8 player_nr, bool daynight)
+static void activate_player_color(sint8 player_nr, bool daynight)
 {
 	// cahces the last settings
 	if(!daynight) {
@@ -671,7 +669,7 @@ static void	activate_player_color(sint8 player_nr, bool daynight)
 		rgbmap_current = rgbmap_all_day;
 	}
 	else {
-		// chaning colortable
+		// changing colortable
 		if(player_night!=player_nr) {
 			int i;
 			player_night = player_nr;
@@ -1291,9 +1289,7 @@ void register_image(struct bild_t* bild)
 
 	// allocate and copy if needed
 	image->recode_flags = FLAG_NORMAL_RECODE | FLAG_REZOOM | (bild->zoomable & FLAG_ZOOMABLE);
-#ifdef NEED_PLAYER_RECODE
 	image->player_flags = NEED_PLAYER_RECODE;
-#endif
 
 	image->base_data = NULL;
 	image->zoom_data = NULL;
@@ -1382,7 +1378,7 @@ void display_set_base_image_offset(unsigned bild, KOORD_VAL xoff, KOORD_VAL yoff
  * Holt Maus X-Position
  * @author Hj. Malthaner
  */
-int gib_maus_x(void)
+int get_maus_x(void)
 {
 	return sys_event.mx;
 }
@@ -1392,7 +1388,7 @@ int gib_maus_x(void)
  * Holt Maus y-Position
  * @author Hj. Malthaner
  */
-int gib_maus_y(void)
+int get_maus_y(void)
 {
 	return sys_event.my;
 }
@@ -1405,16 +1401,22 @@ int gib_maus_y(void)
  */
 static int clip_wh(KOORD_VAL *x, KOORD_VAL *width, const KOORD_VAL min_width, const KOORD_VAL max_width)
 {
+	if (*width <= 0) {
+		*width = 0;
+		return 0;
+	}
 	if (*x < min_width) {
 		const KOORD_VAL xoff = min_width - *x;
 
 		*width += *x-min_width;
 		*x = min_width;
 
-		if (*x + *width >= max_width) *width = max_width - *x;
+		if (*x + *width > max_width) {
+			*width = max_width - *x;
+		}
 
 		return xoff;
-	} else if (*x + *width >= max_width) {
+	} else if (*x + *width > max_width) {
 		*width = max_width - *x;
 	}
 	return 0;
@@ -1431,7 +1433,7 @@ static int clip_lr(KOORD_VAL *x, KOORD_VAL *w, const KOORD_VAL left, const KOORD
 	const KOORD_VAL l = *x;      // leftmost pixel
 	const KOORD_VAL r = *x + *w; // rightmost pixel
 
-	if (l > right || r < left) {
+	if (*w <= 0 || l >= right || r <= left) {
 		*w = 0;
 		return FALSE;
 	}
@@ -1452,7 +1454,7 @@ static int clip_lr(KOORD_VAL *x, KOORD_VAL *w, const KOORD_VAL left, const KOORD
  * Ermittelt Clipping Rechteck
  * @author Hj. Malthaner
  */
-struct clip_dimension display_gib_clip_wh(void)
+struct clip_dimension display_get_clip_wh(void)
 {
 	return clip_rect;
 }
@@ -1461,8 +1463,14 @@ struct clip_dimension display_gib_clip_wh(void)
 /**
  * Setzt Clipping Rechteck
  * @author Hj. Malthaner
+ *
+ * here, a pixel at coordinate xp is displayed if
+ *  clip. x <= xp < clip.xx
+ * the right-most pixel of an image located at xp with width w is displayed if
+ *  clip.x < xp+w <= clip.xx
+ * analogously for the y coordinate
  */
-void display_setze_clip_wh(KOORD_VAL x, KOORD_VAL y, KOORD_VAL w, KOORD_VAL h)
+void display_set_clip_wh(KOORD_VAL x, KOORD_VAL y, KOORD_VAL w, KOORD_VAL h)
 {
 	clip_wh(&x, &w, 0, disp_width);
 	clip_wh(&y, &h, 0, disp_height);
@@ -1552,7 +1560,7 @@ static void display_img_wc(KOORD_VAL h, const KOORD_VAL xp, const KOORD_VAL yp,
 				runlen = *sp++;
 
 				// Hajo: something to display?
-				if (xpos + runlen >= clip_rect.x && xpos <= clip_rect.xx) {
+				if (xpos + runlen > clip_rect.x && xpos < clip_rect.xx) {
 					const int left = (xpos >= clip_rect.x ? 0 : clip_rect.x - xpos);
 					const int len  = (clip_rect.xx - xpos >= runlen ? runlen : clip_rect.xx - xpos);
 
@@ -1857,11 +1865,11 @@ void display_img_aux(const unsigned n, KOORD_VAL xp, KOORD_VAL yp, const int dir
 			xp += images[n].x;
 
 			// use horzontal clipping or skip it?
-			if (xp >= clip_rect.x  &&  xp + w - 1 <= clip_rect.xx) {
+			if (xp >= clip_rect.x  &&  xp + w <= clip_rect.xx) {
 				// marking change?
 				if (dirty) mark_rect_dirty_nc(xp, yp, xp + w - 1, yp + h - 1);
 				display_img_nc(h, xp, yp, sp);
-			} else if (xp <= clip_rect.xx  &&  xp + w > clip_rect.x) {
+			} else if (xp < clip_rect.xx  &&  xp + w > clip_rect.x) {
 				display_img_wc(h, xp, yp, sp);
 				// since height may be reduced, start marking here
 				if (dirty) mark_rect_dirty_wc(xp, yp, xp + w - 1, yp + h - 1);
@@ -1911,7 +1919,7 @@ static void display_color_img_aux(const PIXVAL *sp, KOORD_VAL x, KOORD_VAL y, KO
 				runlen = *sp++;
 
 				// Hajo: something to display?
-				if (xpos + runlen >= clip_rect.x && xpos <= clip_rect.xx) {
+				if (xpos + runlen > clip_rect.x && xpos < clip_rect.xx) {
 					const int left = (xpos >= clip_rect.x ? 0 : clip_rect.x - xpos);
 					const int len  = (clip_rect.xx-xpos > runlen ? runlen : clip_rect.xx - xpos);
 
@@ -1941,27 +1949,28 @@ void display_color_img(const unsigned n, const KOORD_VAL xp, const KOORD_VAL yp,
 			rezoom_img(n);
 		}
 
-		{
-			// first test, if there is a cached version (or we can built one ... )
-			const unsigned char player_flag = images[n].player_flags&0x7F;
-			if ((daynight  ||  night_shift==0)  &&  (player_flag==0  ||  player_flag == player_nr)  ) {
-				if (images[n].player_flags==128  ||  player_flag==0) {
-					recode_color_img(n, player_nr);
-				}
+		if(  daynight  ||  night_shift==0  ) {
+			// Hajo: since the colors for player 0 are already right,
+			// only use the expensive replacement routine for colored images
+			// of other players
+			if(  player_nr==0  ||  (images[n].recode_flags & FLAG_PLAYERCOLOR)==0  ) {
+				display_img_aux(n, xp, yp, dirty, false);
+				return;
+			}
+
+			// first test, if we can/need to build a cached version
+			if(  images[n].player_flags&(~NEED_PLAYER_RECODE)==0  ) {
+				// we can still recoler if needed
+				recode_color_img(n, player_nr);
+			}
+			// ok, there is a cached version
+			if(  (images[n].player_flags&(~NEED_PLAYER_RECODE)) == player_nr  ) {
 				// ok, now we could use the same faster code as for the normal images
 				display_img_aux(n, xp, yp, dirty, true);
 				return;
 			}
 		}
 
-		// Hajo: since the colors for player 0 are already right,
-		// only use the expensive replacement routine for colored images
-		// of other players
-		if ((daynight  ||  night_shift==0)  &&  (player_nr<=0  ||  (images[n].recode_flags & FLAG_PLAYERCOLOR)==0)) {
-			display_img_aux(n, xp, yp, dirty, false);
-			return;
-		}
-
 		// prissi: now test if visible and clipping needed
 		{
 			const KOORD_VAL x = images[n].x;
@@ -1969,7 +1978,7 @@ void display_color_img(const unsigned n, const KOORD_VAL xp, const KOORD_VAL yp,
 			const KOORD_VAL w = images[n].w;
 			const KOORD_VAL h = images[n].h;
 
-			if (h == 0 || xp > clip_rect.xx || yp + y > clip_rect.yy || xp + x + w <= clip_rect.x || yp + y + h <= clip_rect.y) {
+			if (h == 0 || xp + x >= clip_rect.xx || yp + y > clip_rect.yy || xp + x + w <= clip_rect.x || yp + y + h <= clip_rect.y) {
 				// not visible => we are done
 				// happens quite often ...
 				return;
@@ -2012,7 +2021,7 @@ void display_base_img(const unsigned n, const KOORD_VAL xp, const KOORD_VAL yp,
 		const KOORD_VAL w = images[n].base_w;
 		const KOORD_VAL h = images[n].base_h;
 
-		if (h == 0 || xp > clip_rect.xx || yp + y > clip_rect.yy || xp + x + w <= clip_rect.x || yp + y + h <= clip_rect.y) {
+		if (h == 0 || xp + x >= clip_rect.xx || yp + y > clip_rect.yy || xp + x + w <= clip_rect.x || yp + y + h <= clip_rect.y) {
 			// not visible => we are done
 			// happens quite often ...
 			return;
@@ -2178,7 +2187,7 @@ static void display_img_blend_wc(KOORD_VAL h, const KOORD_VAL xp, const KOORD_VA
 				runlen = *sp++;
 
 				// Hajo: something to display?
-				if (xpos + runlen >= clip_rect.x && xpos <= clip_rect.xx) {
+				if (xpos + runlen > clip_rect.x && xpos < clip_rect.xx) {
 					const int left = (xpos >= clip_rect.x ? 0 : clip_rect.x - xpos);
 					const int len  = (clip_rect.xx - xpos >= runlen ? runlen : clip_rect.xx - xpos);
 					p(tp + xpos + left, sp + left, colour, len - left);
@@ -2258,11 +2267,11 @@ void display_img_blend(const unsigned n, KOORD_VAL xp, KOORD_VAL yp, const PLAYE
 			blend_proc pix_blend = (color_index&OUTLINE_FLAG) ? outline[ (color_index&TRANSPARENT_FLAGS)/TRANSPARENT25_FLAG - 1 ] : blend[ (color_index&TRANSPARENT_FLAGS)/TRANSPARENT25_FLAG - 1 ];
 
 			// use horzontal clipping or skip it?
-			if (xp >= clip_rect.x && xp + w - 1 <= clip_rect.xx) {
+			if (xp >= clip_rect.x && xp + w  <= clip_rect.xx) {
 				// marking change?
 				if (dirty) mark_rect_dirty_nc(xp, yp, xp + w - 1, yp + h - 1);
 				display_img_blend_wc( h, xp, yp, sp, color, pix_blend );
-			} else if (xp <= clip_rect.xx && xp + w > clip_rect.x) {
+			} else if (xp < clip_rect.xx && xp + w > clip_rect.x) {
 				display_img_blend_wc( h, xp, yp, sp, color, pix_blend );
 				// since height may be reduced, start marking here
 				if (dirty) mark_rect_dirty_wc(xp, yp, xp + w - 1, yp + h - 1);
@@ -2277,7 +2286,7 @@ void display_img_blend(const unsigned n, KOORD_VAL xp, KOORD_VAL yp, const PLAYE
  * the area of this image need update
  * @author Hj. Malthaner
  */
-void display_mark_img_dirty(unsigned bild, int xp, int yp)
+void display_mark_img_dirty(unsigned bild, KOORD_VAL xp, KOORD_VAL yp)
 {
 	if (bild < anz_images) {
 		mark_rect_dirty_wc(
@@ -2296,7 +2305,7 @@ void display_mark_img_dirty(unsigned bild, int xp, int yp)
  */
 static void display_pixel(KOORD_VAL x, KOORD_VAL y, PIXVAL color)
 {
-	if (x >= clip_rect.x && x <= clip_rect.xx && y >= clip_rect.y && y <= clip_rect.yy) {
+	if (x >= clip_rect.x && x < clip_rect.xx && y >= clip_rect.y && y < clip_rect.yy) {
 		PIXVAL* const p = textur + x + y * disp_width;
 
 		*p = color;
@@ -2374,7 +2383,7 @@ void display_fillbox_wh_clip(KOORD_VAL xp, KOORD_VAL yp, KOORD_VAL w, KOORD_VAL
  */
 static void display_vl_internal(const KOORD_VAL xp, KOORD_VAL yp, KOORD_VAL h, const PLAYER_COLOR_VAL color, int dirty, KOORD_VAL cL, KOORD_VAL cR, KOORD_VAL cT, KOORD_VAL cB)
 {
-	if (xp >= cL && xp <= cR && clip_lr(&yp, &h, cT, cB)) {
+	if (xp >= cL && xp < cR && clip_lr(&yp, &h, cT, cB)) {
 		PIXVAL *p = textur + xp + yp * disp_width;
 		const PIXVAL colval =specialcolormap_all_day[color & 0xFF];
 
@@ -2520,15 +2529,15 @@ static unsigned char get_h_mask(const int xL, const int xR, const int cL, const
 	unsigned char mask;
 
 	// check, if there is something to display
-	if (xR < cL || xL >= cR) return 0;
+	if (xR <= cL || xL >= cR) return 0;
 	mask = 0xFF;
 	// check for left border
-	if (xL < cL && xR >= cL) {
+	if (xL < cL && xR > cL) {
 		// Left border clipped
 		mask = byte_to_mask_array[cL - xL];
 	}
 	// check for right border
-	if (xL < cR && xR >= cR) {
+	if (xL < cR && xR > cR) {
 		// right border clipped
 		mask &= ~byte_to_mask_array[cR - xL];
 	}
@@ -2594,7 +2603,7 @@ int display_text_proportional_len_clip(KOORD_VAL x, KOORD_VAL y, const char* txt
 	}
 
 	// still something to display?
-	if (x > cR || y > cB || y + fnt->height <= cT) {
+	if (x >= cR || y >= cB || y + fnt->height <= cT) {
 		// nothing to display
 		return 0;
 	}
@@ -2974,12 +2983,12 @@ int simgraph_init(KOORD_VAL width, KOORD_VAL height, int full_screen)
 	memset(tile_dirty_old, 255, tile_buffer_length);
 
 	// init player colors
-	for(i=0;  i<MAX_PLAYER;  i++  ) {
+	for(i=0;  i<MAX_PLAYER_COUNT;  i++  ) {
 		player_offsets[i][0] = i*8;
 		player_offsets[i][1] = i*8+24;
 	}
 
-	display_setze_clip_wh(0, 0, disp_width, disp_height);
+	display_set_clip_wh(0, 0, disp_width, disp_height);
 
 	// Hajo: Calculate daylight rgbmap and save it for unshaded tile drawing
 	display_day_night_shift(0);
@@ -3091,7 +3100,7 @@ void simgraph_resize(KOORD_VAL w, KOORD_VAL h)
 		memset(tile_dirty,     255, tile_buffer_length);
 		memset(tile_dirty_old, 255, tile_buffer_length);
 
-		display_setze_clip_wh(0, 0, disp_width, disp_height);
+		display_set_clip_wh(0, 0, disp_width, disp_height);
 	}
 }
 
